@@ -1,11 +1,8 @@
 # This file is part of Tryton.  The COPYRIGHT file at the top level of
 # this repository contains the full copyright notices and license terms.
-from trytond import backend
 from trytond.model import fields
-from trytond.pyson import Eval
-from trytond.pool import PoolMeta, Pool
-
-__all__ = ['Configuration', 'ConfigurationSequence']
+from trytond.pool import Pool, PoolMeta
+from trytond.pyson import Eval, Id
 
 
 class Configuration(metaclass=PoolMeta):
@@ -16,7 +13,8 @@ class Configuration(metaclass=PoolMeta):
             domain=[
                 ('company', 'in', [Eval('context', {}).get('company', -1),
                         None]),
-                ('code', '=', 'sale.opportunity'),
+                ('sequence_type', '=',
+                    Id('sale_opportunity', 'sequence_type_sale_opportunity')),
                 ]))
 
     @classmethod
@@ -38,29 +36,9 @@ class ConfigurationSequence(metaclass=PoolMeta):
         'ir.sequence', "Opportunity Sequence", required=True,
         domain=[
             ('company', 'in', [Eval('company', -1), None]),
-            ('code', '=', 'sale.opportunity'),
-            ],
-        depends=['company'])
-
-    @classmethod
-    def __register__(cls, module_name):
-        TableHandler = backend.get('TableHandler')
-        exist = TableHandler.table_exist(cls._table)
-        if exist:
-            table = cls.__table_handler__(module_name)
-            exist &= table.column_exist('sale_opportunity_sequence')
-
-        super(ConfigurationSequence, cls).__register__(module_name)
-
-        if not exist:
-            cls._migrate_property([], [], [])
-
-    @classmethod
-    def _migrate_property(cls, field_names, value_names, fields):
-        field_names.append('sale_opportunity_sequence')
-        value_names.append('sale_opportunity_sequence')
-        super(ConfigurationSequence, cls)._migrate_property(
-            field_names, value_names, fields)
+            ('sequence_type', '=',
+                Id('sale_opportunity', 'sequence_type_sale_opportunity')),
+            ])
 
     @classmethod
     def default_sale_opportunity_sequence(cls):
