@@ -253,7 +253,7 @@ class SaleOpportunity(
         company = pattern.get('company')
         if not company:
             company = cls.default_company()
-        if company:
+        if company is not None and company >= 0:
             return Company(company).currency.id
 
     @staticmethod
