@@ -2,8 +2,6 @@
 # this repository contains the full copyright notices and license terms.
 from trytond.pool import PoolMeta
 
-__all__ = ['Party', 'Address', 'PartyReplace']
-
 
 class Party(metaclass=PoolMeta):
     __name__ = 'party.party'
@@ -15,11 +13,11 @@ class Address(metaclass=PoolMeta):
     _history = True
 
 
-class PartyReplace(metaclass=PoolMeta):
+class Replace(metaclass=PoolMeta):
     __name__ = 'party.replace'
 
     @classmethod
     def fields_to_replace(cls):
-        return super(PartyReplace, cls).fields_to_replace() + [
+        return super().fields_to_replace() + [
             ('sale.opportunity', 'party'),
             ]
